""" octocat description. """

# Package information
# ===================

__version__ = "0.1.1"
__project__ = "octocat"
__author__ = "Kirill Klenov <horneds@gmail.com>"
__license__ = "BSD"
